import { ActionFormData } from "@minecraft/server-ui";

class CustomUI {
    constructor(typeIndex, title, size = 36) {
        const types = ['§4§r', '§5§r', '§6§r', '§7§r', '§8§r'];
        this.type = types[typeIndex] || '';
        this.ui = new ActionFormData();
        this.title = `${this.type}${title}`;
        this.buttons = [];
        if (this.type === '§8§r' && size > 0) {
            this.buttons = new Array(size).fill(null);
        }
    }

    button(...args) {
        let text, icon, lock, index;
        if (this.type === '§8§r') {
            [text, icon, lock, index] = args;
            if (index >= 0 && index < this.buttons.length) {
                const buttonText = lock ? `§l§o§c§k§r§f${text}` : `§f${text}`;
                this.buttons[index] = { text: buttonText, icon };
            }
        } else {
            [text, icon, lock] = args;
            const buttonText = lock ? `§l§o§c§k§r§f${text}` : `§f${text}`;
            this.buttons.push({ text: buttonText, icon });
        }
    }
    scores(score1, score2) {
        if (this.type === '§4§r') {
            const validateScore = (score) => {
                if (score.toString().length > 9) {
                    //console.warn(`The value ${score} will be truncated to 9 characters.`);
                    return score.toString().slice(0, 9);
                }
                return score;
            };
            this.scores = {
                score1: validateScore(score1),
                score2: validateScore(score2)
            };
        } else {
            //console.warn("addScores() is only available for type 0 (§4§r).");
        }
    }
    body(body) {
        if (this.type === '§5§r') {
            this.ui.body(body);
        } else {
            //console.warn("addBody() is only available for type 1 (§5§r).");
        }
    }
    show(player) {
        this.ui.title(this.title);
        if (this.type === '§4§r' && this.scores) {
            this.ui.body(`split:${this.scores.score1},${this.scores.score2}`);
        }
        if (this.type === '§5§r' && this.bodyText) {
            this.ui.body(this.bodyText);
        }
        if (this.type === '§8§r') {
            for (let i = 0; i < this.buttons.length; i++) {
                if (this.buttons[i] === null) {
                    this.buttons[i] = { text: ``, icon: '' };
                }
                this.ui.button(this.buttons[i].text, this.buttons[i].icon);
            }
        } else {
            for (const button of this.buttons) {
                this.ui.button(button.text, button.icon);
            }
        }
        return this.ui.show(player);
    }
};

export { CustomUI };  